@@ -2,8 +2,8 @@ from collections import defaultdict
 from typing import DefaultDict, List, Set, TYPE_CHECKING, Type
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .blueprint import gRPCMethodsType
-    from .orm import Message
+    from grpcalchemy.blueprint import gRPCMethodsType
+    from grpcalchemy.orm import Message
 
 
 class ServiceMeta:
@@ -18,7 +18,7 @@ class ServiceMeta:
 class ProtoBuffMeta:
     def __init__(self):
         self.import_files: Set[str] = set()
-        self.messages: List[Type[Message]] = []
+        self.messages: List[Type["Message"]] = []
         self.services: List[ServiceMeta] = []
 
 
