@@ -2,10 +2,10 @@ from grpcalchemy.blueprint import Blueprint, grpcmethod
 from grpcalchemy.meta import __meta__
 from grpcalchemy.orm import Message, ReferenceField, StringField
 
-from tests.test_grpcalchemy import TestGrpcalchemy
+from tests.test_grpcalchemy import TestGRPCAlchemy
 
 
-class MetaTestCase(TestGrpcalchemy):
+class MetaTestCase(TestGRPCAlchemy):
     def test_single_message(self):
         class TestMessage(Message):
             name = StringField()
